# rdpower: Power and Sample Size Calculations for RD Designs

The regression discontinuity (RD) design is a popular quasi-experimental design for causal inference and policy evaluation. The `rdpower` package provides tools to perform power, sample size and MDE calculations in RD designs: `rdpower` calculates the power of an RD design, `rdsampsi` calculates the required sample size to achieve a desired power and `rdmde` calculates minimum detectable effects. This package relies on the `rdrobust` package. See Calonico, Cattaneo and Titiunik (2014, 2015) and Calonico, Cattaneo, Farrell and Titiunik (2017). For more details visit [https://rdpackages.github.io/rdpower/](https://rdpackages.github.io/rdpower/).

## References

- Calonico, S., M. D. Cattaneo, M. Farrell and R. Titiunik. (2017). [`rdrobust`: Software for Regression Discontinuity Designs](https://rdpackages.github.io/references/Calonico-Cattaneo-Farrell-Titiunik_2017_Stata.pdf). *Stata Journal* 17(2): 372-404.

- Calonico, S., M. D. Cattaneo, and R. Titiunik. (2014). [`Robust Data-Driven Inference in the Regression-Discontinuity Design`](https://rdpackages.github.io/references/Calonico-Cattaneo-Titiunik_2014_Stata.pdf). *Stata Journal* 14(4): 909-946.

- Calonico, S., M. D. Cattaneo, and R. Titiunik. (2015). [`rdrobust`: An R Package for Robust Nonparametric Inference in Regression-Discontinuity Designs](https://rdpackages.github.io/references/Calonico-Cattaneo-Titiunik_2015_R.pdf). *R Journal* 7(1): 38-51.

- Cattaneo, M. D., R. Titiunik and G. Vazquez-Bare. (2019). [`Power Calculations for Regression Discontinuity Designs`](https://rdpackages.github.io/references/Cattaneo-Titiunik-VazquezBare_2019_Stata.pdf). *Stata Journal*, 19(1): 210-245.

## Authors

- Matias Cattaneo, Princeton University. Email: cattaneo@princeton.edu
- Rocio Titiunik, Princeton University. Email: titiunik@princeton.edu
- Ricardo Masini, UC Davis. Email: rmasini@ucdavis.edu
- Gonzalo Vazquez-Bare, UC Santa Barbara. Email: gvazquez@econ.ucsb.edu